Learn R Programming

ExpBites (version 0.1.3)

ExpBites-package: ExpBites: Analyzing Human Exposure to Mosquito Biting

Description

Tools to analyse human and mosquito behavioral interactions and to compute exposure to mosquito bites estimates. Using behavioral data for human individuals and biting patterns for mosquitoes, you will be able to compute hourly exposure for bed net users and non-users, and summarize (e.g. proportion indoors and outdoors, proportion per time periods, and proportion prevented by bed nets) or visualize these dynamics across a 24-hour cycle.

Arguments

Author

Maintainer: Nicolas Moiroux nicolas.moiroux@ird.fr (ORCID)

See Also