Learn R Programming

ExpBites (version 0.1.3)

gen_df_mosquito: Generate a Simulated Dataset of Hourly Mosquito Biting Rates

Description

Simulates the number of Anopheles mosquito bites occurring indoors and outdoors for each hour of the day. Biting rates follow predefined lambda patterns that reflect typical mosquito activity (e.g., low during the day, peaking at night).

Usage

gen_df_mosquito()

Arguments

Value

A data.frame with the following columns:

hour

Hour of the day (0–23).

indoor_bites

Simulated number of mosquito bites occurring indoors for each hour.

outdoor_bites

Simulated number of mosquito bites occurring outdoors for each hour.

Examples

Run this code
df_bites <- gen_df_mosquito()
head(df_bites)

Run the code above in your browser using DataLab