Learn R Programming

ExpBites (version 0.1.3)

summarise_exposure: Summarize Exposure to Mosquito Bites Over 24h and a Time Interval

Description

Computes daily (24h) and interval-specific exposure statistics for both non-users and bednet users, based on the output of calculate_Exp. Protective efficacy of bednets and proportion of exposure indoors or during the specified interval are computed.

Usage

summarise_exposure(data, interval = c(22, 5))

Value

A tibble with three columns:

type

Character string indicating the category of summary: "non_user_daily", "user_daily", "non_user_interval", "user_interval", "interval_vs_daily" or "net_efficacy".

output

Name of the exposure component or metric (e.g., "Eui", "Euo", "Ep", "Epp", "prop_indoor", etc., "prop_interval_non_user", "prop_interval_user" and "prop_prevented").

value

Numeric value corresponding to the output for the given type.

Arguments

data

A dataframe returned by calculate_Exp(), including columns:

  • Eui, Euo, Eu – indoor, outdoor, and total exposure for non-users,

  • Epi, Epn, Epo, Epp, Ep – indoor, indoor under net, outdoor, prevented, and total exposure for users,

  • hour – hour of the day (0–23).

interval

A numeric vector of length 2 giving the start and end hour (inclusive) of the time interval, e.g., c(22, 5) for 10pm to 5am. Wraps over midnight if needed.

Details

The mathematical model of behavioral interactions is an extension of the killeenQuantifyingBehaviouralInteractions2006;textualExpBites model as previously described in geissbuhlerInterdependenceDomesticMalaria2007;textualExpBites and moirouxHumanExposureEarly2014;textualExpBites

References

Examples

Run this code
# generate fake data 
df <- gen_df_human(n_individuals = 100, hours = c(0:9,17:23))
df_bites <- gen_df_mosquito() 
# calculate mean hourly exposure to bites
exposure_results <- calculate_Exp(df, df_bites)
# summarise exposure estimates
summarise_exposure(exposure_results, interval = c(22, 5))

Run the code above in your browser using DataLab